UnsafeObject

Struct UnsafeObject 

pub struct UnsafeObject { /* private fields */ }
Smart pointer point to object stored in Bump It use TypeId to check when downcast in runtime, so only ’static type supported

Implementations

Source

impl UnsafeObject

pub unsafe fn new<T>(bump: &Bump, inner: T) -> Self
where T: Send + 'static,

Safety

the safety depends on Bump used to create this object not reset or droped while this object is still live

pub fn is<T>(&self) -> bool
where T: 'static,

Check if this object is of type T

pub unsafe fn downcast_ref<T>(&self) -> Option<&T>
where T: 'static,

Safety

The safety depends on Bump used to create this object not reset or droped while this object is still live if this object is of type T, will return the reference of T otherwise will return None

pub unsafe fn downcast_mut<T>(&mut self) -> Option<&mut T>
where T: 'static,

Safety

The safety depends on Bump used to create this object not reset or droped while this object is still live if this object is of type T, will return the mutable reference of T otherwise will return None