BumpAlloc trait and implemention TokioBumpAlloc
Structs
- Tokio
Bump Alloc - Allocate object in Bump within async task when dropped ,it will spawn a task to wait all BumpRef dropped. when all BumpRef dropped,it will drop RecycleableBump,and the Bump will be reset and release back to pool
Traits
- Bump
Alloc - BumpObject alloc trait