pub struct TokioBumpAlloc { /* private fields */ }Expand description
Allocate object in Bump within async task when dropped ,it will spawn a task to wait all BumpRef dropped. when all BumpRef dropped,it will drop RecycleableBump,and the Bump will be reset and release back to pool
Implementations
Sourceimpl TokioBumpAlloc
impl TokioBumpAlloc
pub fn new(handle: Handle, bump: RecycleableBump) -> Self